#Include the Client API lib
import asyncio
import aiohttp
import json
import SideeXWebServiceClientAPI

ProtocolType = SideeXWebServiceClientAPI.ProtocolType
SideeXWebServiceClient = SideeXWebServiceClientAPI.SideeXWebServiceClientAPI

async def delay(time):
    await asyncio.sleep(time)

if __name__=="__main__":
    #Connect to a SideeX WebService server
    ws_client = SideeXWebServiceClient('http://127.0.0.1:50000', ProtocolType.HTTP)
    file = open('D:/workspace/sideex-webservice-client-api-java/testcase.zip','rb')

    #//Gets SideeX WebService server status
    print(asyncio.run(ws_client.echo()))
    
    token = json.loads(asyncio.run(ws_client.runTestSuite(file)))['token']# get the token
    flag = False

    #Check the execution state every 2 seconds
    while not flag:

        #Get the current state
        state = json.loads(asyncio.run(ws_client.getState(token)))['webservice']['state']# get the WebService current state
        if (state != "complete" and state != "error"):
            print(state)
            asyncio.run(delay(2))
        #If test is error
        elif state == "error":
            flag = True
        #If test is complete
        else:
            print(state)
            froamData = aiohttp.FormData()
            froamData.add_field('token', token, content_type='application/x-www-form-urlencoded')
            froamData.add_field('file', "reports.zip", content_type='application/x-www-form-urlencoded')
            #download the test report to the target file path
            asyncio.run(ws_client.download( froamData, "./reports.zip", 0))

            #Download the logs
            froamData = aiohttp.FormData()
            froamData.add_field('token', token, content_type='application/x-www-form-urlencoded')
            asyncio.run(ws_client.download( froamData, "./logs.zip", 1))

            #Delete the test case and report from the server
            print(asyncio.run(ws_client.deleteJob(token)))

            flag = True



import json
import asyncio
import aiohttp
import os
import ssl
from enum import Enum

class ProtocolType(Enum):
    HTTP = 0
    HTTPS_DISABLE = 1
    HTTPS_ENABLE = 2

class SideeXWebServiceClientAPI():
    def __init__(self, baseURL, protocolType=ProtocolType.HTTP, caFilePath=None):
        self.baseURL = baseURL
        self.protocolType = protocolType
        self.caFilePath = caFilePath
        self.sslContext = None

        if self.baseURL[-1] != '/':
            self.baseURL = self.baseURL + "/"

        if self.protocolType == ProtocolType.HTTPS_DISABLE:
            self.sslContext = False
        elif self.protocolType == ProtocolType.HTTPS_ENABLE:
            self.sslContext = ssl.create_default_context(cafile=self.caFilePath)

    async def echo(self):
        async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(ssl=self.sslContext)) as session:
            # data = aiohttp.FormData()
            # data.add_field('token', token, content_type='application/x-www-form-urlencoded')

            async with session.get(self.baseURL+"sideex-webservice/echo") as resp:
                return await resp.text()

    async def runTestSuite(self, file):
        async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(ssl=self.sslContext)) as session:
            data = aiohttp.FormData()
            data.add_field('file', file, filename=os.path.basename(file.name), content_type='application/x-www-form-urlencoded')
            async with session.post(self.baseURL+"sideex-webservice/runTestSuites", data = data) as resp:
                return await resp.text()
    
    async def getState(self, token):
        async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(ssl=self.sslContext)) as session:
            data = aiohttp.FormData()
            data.add_field('token', token, content_type='application/x-www-form-urlencoded')

            async with session.get(self.baseURL+"sideex-webservice/getState", data = data) as resp:
                return await resp.text()

    async def download(self, formData, filePath, option):
        tempURL = self.baseURL
        if option == 0:
            tempURL = tempURL + "sideex-webservice/downloadReports"
        else:
            tempURL = tempURL + "sideex-webservice/downloadLogs"

        async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(ssl=self.sslContext)) as session:
            async with session.get(tempURL, data = formData) as resp:
                test = await resp.read()
                with open(filePath, "wb") as f:
                    f.write(test)
    
    async def deleteJob(self, token):
        async with aiohttp.ClientSession(connector=aiohttp.TCPConnector(ssl=self.sslContext)) as session:
            data = aiohttp.FormData()
            data.add_field('token', token, content_type='application/x-www-form-urlencoded')

            async with session.post(self.baseURL+"sideex-webservice/deleteJob", data = data) as resp:
                return await resp.text()



import setuptools

with open("README.md", "r") as readme_file:
    README = readme_file.read()

setuptools.setup(
    name='sideex-webservice-client',
    version='0.9.2-2',
    author='SideeX Team',
    author_email='feedback@sideex.io',
    description='SideeX WebService Client API for Python handles the transfer of test suites to a self-hosted SideeX WebService server and returns the test reports.',
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/SideeX/sideex-webservice-client-api-python",
    packages=setuptools.find_packages(),
    classifiers=[  # Optional
      #   3 - Alpha
      #   4 - Beta
      #   5 - Production/Stable
      'Development Status :: 3 - Alpha',

      'Intended Audience :: Developers',
      'Topic :: Software Development :: Build Tools',

      'License :: OSI Approved :: MIT License',

      'Programming Language :: Python :: 3',
      'Programming Language :: Python :: 3.4',
      'Programming Language :: Python :: 3.5',
      'Programming Language :: Python :: 3.6',
      'Programming Language :: Python :: 3.7',
    ],
    python_requires='>=3',
)